@@ -18,7 +18,7 @@ class Parser(object):
                        max_memory=128000000,
                        disjunct_cost=10000,
                        max_sentence_length=170):
-        locale.setlocale(locale.LC_ALL,"en_US.UTF8")
+        locale.setlocale(locale.LC_ALL,"en_US.UTF-8")
         
         #We need to retain all these options cause we will
         #recreate the parse_options if the parser starts failing
